@@ -1,31 +1,88 @@
+# cbinduneven.old=function(li) {
+#   # bind a list of data frame or named vector that are not of the same length
+#   allnames=lapply(li, rownames)
+#   alllen=lapply(allnames, length)
+#   #nams = allnames[[which.max(alllen)]]
+#   nams = allnames[[1]]# so that the rows are added consecutively
+#   nams= c(nams, setdiff(unique(unlist(allnames)), nams)) # append additional names
+#   if (any(nams=="")) stop("cbinduneven: empty rownames are not allowed:\n"%.%concatList(nams,"|"))
+#   #myprint(nams)
+#   
+#   res=NULL
+#   for (i in 1:length(li)){
+#     a=li[[i]]
+#     if (is.table(a)) a=as.matrix(a,ncol=1)
+#     p=ncol(a)
+#     toadd = matrix(NA, nrow=length(nams), ncol=p, dimnames=list(nams,colnames(a)))
+#     toadd[rownames(a),]=as.matrix(a)
+#     tmp=as.data.frame(toadd, stringsAsFactors=FALSE)
+#     if(ncol(tmp)==1) names(tmp)=names(li)[i] else names(tmp)=names(li)[i]%.%names(tmp) 
+#     if (i==1) {
+#       res=tmp # cbind NULL and tmp doesn't work
+#     } else {
+#       res=cbind(res,tmp)
+#     }
+#   }
+#   res
+# }
+
+# bind a list of data frames or named vector that are not of the same length
 cbinduneven=function(li) {
-    # bind a list of data frame or named vector that are not of the same length
-    allnames=lapply(li, rownames)
-    alllen=lapply(allnames, length)
-    #nams = allnames[[which.max(alllen)]]
-    nams = allnames[[1]]# so that the rows are added consecutively
-    nams= c(nams, setdiff(unique(unlist(allnames)), nams)) # append additional names
-    if (any(nams=="")) stop("cbinduneven: empty rownames are not allowed:\n"%.%concatList(nams,"|"))
-    #myprint(nams)
+  
+  # make sure all elements are data frames or vectors. if it is a vector, convert to a data frame
+  li = lapply(li, function(x) {
+    if (is.data.frame(x)) {
+       # do nothing
+      x
+      
+    } else if (is.vector(x)) {
+      if (is.null(names(x))) stop("vectors need to be named") else data.frame(x)
     
-    res=NULL
-    for (i in 1:length(li)){
-        a=li[[i]]
-        if (is.table(a)) a=as.matrix(a,ncol=1)
-        p=ncol(a)
-        toadd = matrix(NA, nrow=length(nams), ncol=p, dimnames=list(nams,colnames(a)))
-        toadd[rownames(a),]=as.matrix(a)
-        tmp=as.data.frame(toadd, stringsAsFactors=FALSE)
-        if(ncol(tmp)==1) names(tmp)=names(li)[i] else names(tmp)=names(li)[i]%.%names(tmp) 
-        if (i==1) {
-            res=tmp # cbind NULL and tmp doesn't work
-        } else {
-            res=cbind(res,tmp)
-        }
+    } else if (is.table(x)) {
+      tab=x
+      x <- as.integer(tab)
+      names(x) <- names(tab)
+      data.frame(x)
+      
+    } else if (is.matrix(x)) {
+      x <- unique(x, MARGIN = 1)
+      data.frame(x, row.names = rownames(x))
+      
+    } else {
+      stop ("vectors need to be named vectors or data frames")
     }
-    res
+  })
+  
+  allnames=lapply(li, rownames)
+  nams = allnames[[1]]# so that the rows are added consecutively
+  nams= c(nams, setdiff(unique(unlist(allnames)), nams)) # append additional names
+  if (any(nams=="")) stop("cbinduneven: empty rownames are not allowed:\n"%.%concatList(nams,"|"))
+  #myprint(nams)
+  
+  add_na_row <- function(df, row_name) {
+    if (!(row_name %in% rownames(df))) {
+      new_row <- data.frame(matrix(NA, ncol = ncol(df)))
+      colnames(new_row) <- colnames(df)
+      df <- rbind(df, new_row)
+      rownames(df)[nrow(df)] <- row_name
+    }
+    return(df)
+  }
+  
+  li = lapply(li, function (x) {
+    new=setdiff(nams, rownames(x))
+    for (i in new) x <- add_na_row(x, i)
+    x[nams,]
+  })  
+  
+  do.call(cbind, li)
 }
 
+# # test code
+# a=data.frame("x"=1:2)
+# b=data.frame("y"=3:5);#rownames(b)[3]=""
+# cbinduneven(list(a,b))
+
 
 
 # returns binary representation of an integer
