@@ -53,12 +53,12 @@ getFormattedSummary=function(fits, type=12, est.digits=2, se.digits=2, robust, r
         if(ncol(tmp)>1) {
             lb=tmp[,3,drop=FALSE]
             lb[too.big]=NA
-            lb=formatDouble(lb, est.digits, remove.leading0=remove.leading0) 
+            lb=ifelse(trunc.large.est & lb>100, ">100", formatDouble(lb, est.digits, remove.leading0=remove.leading0) )
             if(to.trim) lb=trim(lb)
             
             ub=tmp[,4,drop=FALSE]
             ub[too.big]=NA
-            ub=formatDouble(ub, est.digits, remove.leading0=remove.leading0) 
+            ub=ifelse(trunc.large.est & ub>100, ">100", formatDouble(ub, est.digits, remove.leading0=remove.leading0) )
             if(to.trim) ub=trim(ub)
         }
                 
@@ -71,8 +71,11 @@ getFormattedSummary=function(fits, type=12, est.digits=2, se.digits=2, robust, r
             # est (se)
             out=est. %.% " (" %.% formatDouble(tmp[,2,drop=FALSE], se.digits, remove.leading0=remove.leading0) %.% ")" %.% ifelse (round(tmp[,p.val.col],3)<=0.05, ifelse (tmp[,p.val.col]<0.01,"**","*"),"")
         else if (type==3) 
-            # est (lb, up)
-            out=est. %.% " (" %.% lb %.% ", " %.% ub %.% ")" 
+            # est (lb, ub)
+            out=est. %.% " (" %.% lb %.% "-" %.% ub %.% ")" 
+        else if (type==7)
+          # (lb, ub)
+          out=ifelse(drop(too.big), rep("",nrow(lb)), " (" %.% lb %.% ", " %.% ub %.% ")")
         else if (type==4)
             # a space is inserted between est and se, they could be post-processed in swp
             out=est. %.% " " %.% formatDouble(tmp[,2,drop=FALSE], est.digits, remove.leading0=remove.leading0)
@@ -83,9 +86,6 @@ getFormattedSummary=function(fits, type=12, est.digits=2, se.digits=2, robust, r
         else if (type==6)
             # est (pval)*
             out=est. %.% " (" %.% formatDouble(tmp[,p.val.col,drop=FALSE], 3, remove.leading0=remove.leading0) %.% ")" %.% ifelse (round(tmp[,p.val.col],3)<=0.05,ifelse (tmp[,p.val.col]<0.01,"**","*"),"")
-        else if (type==7)
-            # (lb, up)
-            out=ifelse(drop(too.big), rep("",nrow(lb)), " (" %.% lb %.% ", " %.% ub %.% ")")
         else if (type==8)
             # est (p value #)
             out=est. %.% " (p value " %.% 
@@ -107,9 +107,6 @@ getFormattedSummary=function(fits, type=12, est.digits=2, se.digits=2, robust, r
                 " (CI=" %.% lb %.% "," %.% ub %.% 
                 ", p=" %.% formatDouble(tmp[,p.val.col,drop=FALSE], 3, remove.leading0=remove.leading0) %.% ")" %.%
                 ifelse (round(tmp[,p.val.col],3)<=0.05,ifelse (tmp[,p.val.col]<0.01,"**","*"),"") 
-        else if (type==13) 
-            # (lb-up)
-            out="(" %.% lb %.% "-" %.% ub %.% ")" 
         else 
             stop ("getFormattedSummaries(). type not supported: "%.%type)
             
